AccessResponseBase

Struct AccessResponseBase 

pub struct AccessResponseBase {
    pub response_base: ResponseBase,
    pub credits: u64,
    pub top_hash: String,
}
Definition. A base for RPC response types that support RPC payment.

Fields

response_base: ResponseBase

A flattened ResponseBase.

credits: u64

If payment for RPC is enabled, the number of credits available to the requesting client. Otherwise, 0.

top_hash: String

If payment for RPC is enabled, the hash of the highest block in the chain. Otherwise, empty.

Implementations

Source

impl AccessResponseBase

pub const OK: Self

Status::Ok and trusted Self.

This is the most common version of Self.

use cuprate_rpc_types::{misc::*, base::*};

assert_eq!(AccessResponseBase::OK, AccessResponseBase {
    response_base: ResponseBase::OK,
    credits: 0,
    top_hash: "".into(),
});
pub const OK_UNTRUSTED: Self

Same as Self::OK but with untrusted set to true.

use cuprate_rpc_types::{misc::*, base::*};

assert_eq!(AccessResponseBase::OK_UNTRUSTED, AccessResponseBase {
    response_base: ResponseBase::OK_UNTRUSTED,
    credits: 0,
    top_hash: "".into(),
});
pub const fn new(response_base: ResponseBase) -> Self

Creates a new Self with default values.

Since RPC payment is semi-deprecated, Self::credits and Self::top_hash will always be set to the default values.

use cuprate_rpc_types::{misc::*, base::*};

let new = AccessResponseBase::new(ResponseBase::OK);
assert_eq!(new, AccessResponseBase {
    response_base: ResponseBase::OK,
    credits: 0,
    top_hash: "".into(),
});